camelot.camelot.view.filters.ComboBoxFilter

Package camelot :: Package camelot :: Package view :: Module filters :: Class ComboBoxFilter |
[hide private]
[frames] | no frames]

# Class ComboBoxFilter

source code

Filter where the items are displayed in a QComboBox

Instance Methods | [hide private]
render(self, parent, name, options) Render this filter as a qt object | source code
Inherited from `Filter`: `__init__`, `get_name_and_options` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### render(self, parent, name, options) | source code
Render this filter as a qt object Parameters: `parent` - its parent widget `name` - the name of the filter `options` - the options that can be selected, where each option is a list of tuples containting (option_name, query_decorator) The name and the list of options can be fetched with get_name_and_options Overrides: Filter.render (inherited documentation)